@@ -192,6 +192,10 @@ main( int argc, char *argv[] )
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 
+	/* bootstrap message logging (stage 0)
+	*/
+	mlog_init0();
+
 	/* Get the parent's pid. will be used in signal handling
 	 * to differentiate parent from children.
 	 */
@@ -233,7 +237,7 @@ main( int argc, char *argv[] )
 			if ( ! optarg || optarg[ 0 ] == '-' ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c argument missing\n"),
-				      optopt );
+				      c );
 				usage( );
 				return mlog_exit(EXIT_ERROR, RV_OPT);
 			}
@@ -244,7 +248,7 @@ main( int argc, char *argv[] )
 			     errno == ERANGE ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c argument (%s) invalid\n"),
-				      optopt,
+				      c,
 				      optarg );
 				usage( );
 				return mlog_exit(EXIT_ERROR, RV_OPT);
@@ -255,7 +259,7 @@ main( int argc, char *argv[] )
 			if ( ! optarg || optarg[ 0 ] == '-' ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c argument missing\n"),
-				      optopt );
+				      c );
 				usage( );
 				return mlog_exit(EXIT_ERROR, RV_OPT);
 			}
@@ -266,7 +270,7 @@ main( int argc, char *argv[] )
 			     errno == ERANGE ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c argument (%s) invalid\n"),
-				      optopt,
+				      c,
 				      optarg );
 				usage( );
 				return mlog_exit(EXIT_ERROR, RV_OPT);
@@ -284,7 +288,7 @@ main( int argc, char *argv[] )
 			if ( ! optarg || optarg[ 0 ] == '-' ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c argument missing\n"),
-				      optopt );
+				      c );
 				usage( );
 				return mlog_exit(EXIT_ERROR, RV_OPT);
 			}
@@ -1222,14 +1226,14 @@ loadoptfile( intgen_t *argcp, char ***argvp )
 			if ( ! optarg || optarg[ 0 ] == '-' ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c argument missing\n"),
-				      optopt );
+				      c );
 				usage( );
 				return BOOL_FALSE;
 			}
 			if ( optfilename ) {
 				mlog( MLOG_NORMAL | MLOG_ERROR | MLOG_NOLOCK,
 				      _("-%c allowed only once\n"),
-				      optopt );
+				      c );
 				usage( );
 				return BOOL_FALSE;
 			}
