@@ -1,37 +1,23 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2001 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <libxfs.h>
-#include <jdm.h>
+#include <xfs/xfs.h>
+#include <xfs/jdm.h>
 
 #include <time.h>
 #include <fcntl.h>
@@ -58,7 +44,7 @@ init_idb( void *pred, inv_predicate_t bywhat, inv_oflag_t forwhat,
 	char fname[ INV_STRLEN ];
 	char uuname[ INV_STRLEN ];
 	int fd;
-	
+
 	*tok = INV_TOKEN_NULL;
 	/* make sure INV_DIRPATH exists, and is writable */
 	if ( make_invdirectory( forwhat ) < 0 )
@@ -170,7 +156,7 @@ invmgr_query_all_sessions (
 		return BOOL_TRUE;
 	}
 	if ( fd < 0 || numfs <= 0 ) {
-		mlog( MLOG_NORMAL | MLOG_INV, "INV: Error in fstab\n" );
+		mlog( MLOG_NORMAL | MLOG_INV, _("INV: Error in fstab\n") );
 		return BOOL_FALSE;
 	}
 	
@@ -180,16 +166,16 @@ invmgr_query_all_sessions (
 		if ( fstab_get_fname( &arr[i].ft_uuid, fname, 
 				     (inv_predicate_t)INV_BY_UUID,
 				     forwhat) < 0 ) {
-			mlog( MLOG_NORMAL | MLOG_INV,
-			     "INV: Cant get inv-name for uuid\n"
+			mlog( MLOG_NORMAL | MLOG_INV, _(
+			     "INV: Cant get inv-name for uuid\n")
 			     );
 			return BOOL_FALSE;
 		}
 		strcat( fname, INV_INVINDEX_PREFIX );
 		invfd = open( fname, INV_OFLAG(forwhat) );
 		if ( invfd < 0 ) {
-			mlog( MLOG_NORMAL | MLOG_INV,
-			     "INV: Open failed on %s\n", 
+			mlog( MLOG_NORMAL | MLOG_INV, _(
+			     "INV: Open failed on %s\n"),
 			     fname
 			     );
 			return BOOL_FALSE;
@@ -468,19 +454,18 @@ invmgr_inv_check(
 		
 		if ((iarr[i].ie_timeperiod.tp_start != harr[0].sh_time) ||
 		    (iarr[i].ie_timeperiod.tp_end != harr[nsess-1].sh_time)) {
-			printf("INV: Check %d failed.\n", i+1);
-			printf("invidx (%d)\t%d - %d\n",
+			printf(_("INV: Check %d failed.\n"), i+1);
+			printf(_("invidx (%d)\t%d - %d\n"),
 			       i+1,
 			       iarr[i].ie_timeperiod.tp_start,
 			       iarr[i].ie_timeperiod.tp_end);
 			for( s = 0; s < nsess; s++ ) {
-				printf("tm (%d)\t%d\n", s, harr[s].sh_time);
+				printf(_("tm (%d)\t%d\n"), s, harr[s].sh_time);
 			}
 		}
 		else {
-			printf("INV: Check %d out of %d succeeded\n", 
+			printf(_("INV: Check %d out of %d succeeded\n"),
 			       i+1, nindices);
-
 		}
 		INVLOCK( fd, LOCK_UN );
 		close( fd );
@@ -600,7 +585,7 @@ insert_session( invt_sessinfo_t *s)
 				  &tok ) ) < 0 ) {
 		if ( tok == INV_TOKEN_NULL ) {
 #ifdef INVT_DEBUG
-			mlog( MLOG_NORMAL | MLOG_INV, "INV: insert_session: init_db "
+			mlog( MLOG_DEBUG | MLOG_INV, "INV: insert_session: init_db "
 			      "failed\n" );
 #endif
 			return BOOL_FALSE;
@@ -696,7 +681,7 @@ make_invdirectory( inv_oflag_t forwhat )
 		}
 	}
 
-	mlog( MLOG_VERBOSE | MLOG_INV, "%s created\n", path );
+	mlog( MLOG_VERBOSE | MLOG_INV, _("%s created\n"), path );
 	return 1;
 }
 
@@ -707,7 +692,7 @@ invmgr_lockinit( void )
 {
 	if ( invlock_fd == -1 ) {
 		if (( invlock_fd = open( INV_LOCKFILE, 
-					O_RDONLY | O_CREAT )) < 0 ) {
+					O_RDONLY | O_CREAT, S_IRUSR|S_IWUSR )) < 0 ) {
 			INV_PERROR( INV_LOCKFILE );
 			return BOOL_FALSE;
 		}
@@ -742,10 +727,3 @@ invmgr_unlock( void )
 
 #endif
 
-
-
-
-
-
-
-
